@@ -7,7 +7,7 @@ import androidx.work.WorkManager
 import com.badlogic.gdx.backends.android.AndroidApplication
 import com.badlogic.gdx.backends.android.AndroidApplicationConfiguration
 import com.unciv.logic.files.UncivFiles
-import com.unciv.ui.components.Fonts
+import com.unciv.ui.components.fonts.Fonts
 import com.unciv.utils.Display
 import com.unciv.utils.Log
 import java.io.File
@@ -44,7 +44,7 @@ open class AndroidLauncher : AndroidApplication() {
         Display.setOrientation(settings.displayOrientation)
         Display.setCutout(settings.androidCutout)
 
-        game = AndroidGame()
+        game = AndroidGame(this)
         initialize(game, config)
 
         game!!.setDeepLinkedGame(intent)
@@ -61,7 +61,8 @@ open class AndroidLauncher : AndroidApplication() {
         val internalModsDir = File("${filesDir.path}/mods")
 
         // Mod directory in the shared app data (where the user can see and modify)
-        val externalModsDir = File("${getExternalFilesDir(null)?.path}/mods")
+        val externalPath = getExternalFilesDir(null)?.path ?: return
+        val externalModsDir = File("$externalPath/mods")
 
         // Copy external mod directory (with data user put in it) to internal (where it can be read)
         if (!externalModsDir.exists()) externalModsDir.mkdirs() // this can fail sometimes, which is why we check if it exists again in the next line
@@ -70,7 +71,7 @@ open class AndroidLauncher : AndroidApplication() {
 
     override fun onPause() {
         val game = this.game!!
-        if (game.isInitialized
+        if (game.isInitializedProxy()
                 && game.gameInfo != null
                 && game.settings.multiplayer.turnCheckerEnabled
                 && game.files.getMultiplayerSaves().any()
