@@ -5,5 +5,6 @@ import com.unciv.logic.IsPartOfGameInfoSerialization
 enum class DiplomaticStatus : IsPartOfGameInfoSerialization {
     Peace,
     Protector,  //city state's diplomacy for major civ can be marked as Protector, not vice versa.
-    War
+    War,
+    DefensivePact,
 }
