@@ -6,7 +6,7 @@ import com.unciv.logic.IsPartOfGameInfoSerialization
 import com.unciv.logic.trade.TradeType.TradeTypeNumberType
 import com.unciv.models.ruleset.Speed
 import com.unciv.models.translations.tr
-import com.unciv.ui.components.Fonts
+import com.unciv.ui.components.fonts.Fonts
 
 data class TradeOffer(val name: String, val type: TradeType, var amount: Int = 1, var duration: Int) : IsPartOfGameInfoSerialization {
 
@@ -25,7 +25,7 @@ data class TradeOffer(val name: String, val type: TradeType, var amount: Int = 1
 
     constructor() : this("", TradeType.Gold, duration = -1) // so that the json deserializer can work
 
-    @Suppress("CovariantEquals")    // This is an overload, not an override of the built-in equals(Any?)
+    @Suppress("CovariantEquals", "WrongEqualsTypeParameter")    // This is an overload, not an override of the built-in equals(Any?)
     fun equals(offer: TradeOffer): Boolean {
         return offer.name == name
                 && offer.type == type
@@ -44,7 +44,7 @@ data class TradeOffer(val name: String, val type: TradeType, var amount: Int = 1
                 city?.run { "{$name} (${population.population})" } ?: "Non-existent city"
             }
             else -> name
-        }.tr()
+        }.tr(hideIcons = true)
 
         if (type.numberType == TradeTypeNumberType.Simple || type.numberType == TradeTypeNumberType.Gold) offerText += " ($amount)"
         else if (name == Constants.researchAgreement) offerText += " (-$amount${Fonts.gold})"
