@@ -41,7 +41,8 @@ enum class UniqueTarget(
     Wonder(inheritsFrom = Building),
 
     // Unit-specific
-    Unit("Uniques that can be added to units, unit types, or promotions", inheritsFrom = UnitTriggerable),
+    UnitAction("Uniques that affect a unit's actions, and can be modified by UnitActionModifiers", inheritsFrom = UnitTriggerable),
+    Unit("Uniques that can be added to units, unit types, or promotions", inheritsFrom = UnitAction),
     UnitType(inheritsFrom = Unit),
     Promotion(inheritsFrom = Unit),
 
@@ -61,7 +62,7 @@ enum class UniqueTarget(
     Conditional("Modifiers that can be added to other uniques to limit when they will be active", modifierType = ModifierType.Conditional),
     TriggerCondition("Special conditionals that can be added to Triggerable uniques, to make them activate upon specific actions.", inheritsFrom = Global, modifierType = ModifierType.Other),
     UnitTriggerCondition("Special conditionals that can be added to UnitTriggerable uniques, to make them activate upon specific actions.", inheritsFrom = TriggerCondition, modifierType = ModifierType.Other),
-    UnitActionModifier("Modifiers that can be added to unit action uniques as conditionals", modifierType = ModifierType.Other),
+    UnitActionModifier("Modifiers that can be added to UnitAction uniques as conditionals", modifierType = ModifierType.Other),
     ;
 
     /** Whether a UniqueType is allowed in the `<conditional or trigger>` part - or not.
