@@ -16,7 +16,6 @@ import com.unciv.ui.components.input.onChange
 import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.screens.victoryscreen.LoadMapPreview
 import com.unciv.utils.Concurrency
-import io.ktor.util.collections.ConcurrentSet
 import kotlinx.coroutines.Job
 import kotlinx.coroutines.isActive
 import com.badlogic.gdx.utils.Array as GdxArray
@@ -35,7 +34,7 @@ class MapFileSelectTable(
     private class MapWrapper(val fileHandle: FileHandle, val mapParameters: MapParameters) {
         override fun toString(): String = mapParameters.baseRuleset + " | " + fileHandle.name()
     }
-    private val mapWrappers = ConcurrentSet<MapWrapper>()
+    private val mapWrappers = ArrayList<MapWrapper>()
 
     private val columnWidth = newGameScreen.getColumnWidth()
 
@@ -54,45 +53,50 @@ class MapFileSelectTable(
 
         mapFileSelectBox.onChange { onSelectBoxChange() }
 
-        addMapWrappersSemiAsync()
+        addMapWrappersAsync()
     }
 
-    private fun addMapWrappersSemiAsync(){
-        val mapFilesSequence = sequence<FileHandle> {
-            yieldAll(MapSaver.getMaps().asSequence())
-            for (modFolder in RulesetCache.values.mapNotNull { it.folderLocation }) {
-                val mapsFolder = modFolder.child(MapSaver.mapsFolder)
-                if (mapsFolder.exists())
-                    yieldAll(mapsFolder.list().asSequence())
-            }
-        }.sortedByDescending { it.lastModified() }
+    private fun getMapFilesSequence() = sequence<FileHandle> {
+        yieldAll(MapSaver.getMaps().asSequence())
+        for (modFolder in RulesetCache.values.mapNotNull { it.folderLocation }) {
+            val mapsFolder = modFolder.child(MapSaver.mapsFolder)
+            if (mapsFolder.exists())
+                yieldAll(mapsFolder.list().asSequence())
+        }
+    }.sortedByDescending { it.lastModified() }
 
-        // We only really need ONE map to be loaded to tell us "isNotEmpty" and "recentlySavedMapExists"
-        // The rest we can defer, so that users don't get ANRs when opening the new game screen
-        //   because the game wants to load ALL the maps before first render
-        fun tryAddMapFile(mapFile: FileHandle){
-            val mapParameters = try {
-                MapSaver.loadMapParameters(mapFile)
+    private fun addMapWrappersAsync(){
+        val mapFilesSequence = getMapFilesSequence()
+
+        Concurrency.run {
+            for (mapFile in mapFilesSequence) {
+                val mapParameters = try {
+                    MapSaver.loadMapParameters(mapFile)
+                } catch (_: Exception) {
+                    continue
+                }
+                mapWrappers.add(MapWrapper(mapFile, mapParameters))
+            }
+            Concurrency.runOnGLThread { fillMapFileSelectBox() }
+        }
+    }
+
+
+    private val firstMap: FileHandle? by lazy {
+        getMapFilesSequence().firstOrNull {
+            try {
+                MapSaver.loadMapParameters(it)
+                true
             } catch (_: Exception) {
-                return
+                false
             }
-            mapWrappers.add(MapWrapper(mapFile, mapParameters))
-        }
-
-        for (mapFile in mapFilesSequence) {
-            if (mapWrappers.isEmpty()) tryAddMapFile(mapFile)
-            // Each other map is loaded in another thread, so we can multiplex the IO and CPU capabilities
-            else Concurrency.run { tryAddMapFile(mapFile) }
         }
     }
 
+    fun isNotEmpty() = firstMap != null
+    fun recentlySavedMapExists() = firstMap!=null && firstMap!!.lastModified() > System.currentTimeMillis() - 900000
 
-    fun isNotEmpty() = mapWrappers.isNotEmpty()
-    fun recentlySavedMapExists() = mapWrappers.any {
-        it.fileHandle.lastModified() > System.currentTimeMillis() - 900000
-    }
-
-    fun fillMapFileSelectBox() {
+    private fun fillMapFileSelectBox() {
         if (!mapFileSelectBox.items.isEmpty) return
 
         val mapFiles = GdxArray<MapWrapper>()
