@@ -19,7 +19,7 @@ import com.unciv.models.metadata.GameSetupInfo
 import com.unciv.models.ruleset.Ruleset
 import com.unciv.models.ruleset.RulesetCache
 import com.unciv.models.translations.tr
-import com.unciv.ui.components.ExpanderTab
+import com.unciv.ui.components.widgets.ExpanderTab
 import com.unciv.ui.components.extensions.addSeparator
 import com.unciv.ui.components.extensions.addSeparatorVertical
 import com.unciv.ui.components.extensions.disable
@@ -45,7 +45,7 @@ import kotlinx.coroutines.coroutineScope
 import java.net.URL
 import java.util.UUID
 import kotlin.math.floor
-import com.unciv.ui.components.AutoScrollPane as ScrollPane
+import com.unciv.ui.components.widgets.AutoScrollPane as ScrollPane
 
 class NewGameScreen(
     defaultGameSetupInfo: GameSetupInfo? = null,
@@ -407,4 +407,3 @@ class NewGameScreen(
 
     override fun recreate(): BaseScreen = NewGameScreen(gameSetupInfo)
 }
-
